==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/inputs/KeyVaultPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.inputs

import com.pulumi.azurenative.kusto.inputs.KeyVaultPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of the key vault.
 * @property keyName The name of the key vault key.
 * @property keyVaultUri The Uri of the key vault.
 * @property keyVersion The version of the key vault key.
 * @property userIdentity The user assigned identity (ARM resource id) that has access to the key.
 */
public data class KeyVaultPropertiesArgs(
    public val keyName: Output<String>? = null,
    public val keyVaultUri: Output<String>? = null,
    public val keyVersion: Output<String>? = null,
    public val userIdentity: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.kusto.inputs.KeyVaultPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.kusto.inputs.KeyVaultPropertiesArgs =
        com.pulumi.azurenative.kusto.inputs.KeyVaultPropertiesArgs.builder()
            .keyName(keyName?.applyValue({ args0 -> args0 }))
            .keyVaultUri(keyVaultUri?.applyValue({ args0 -> args0 }))
            .keyVersion(keyVersion?.applyValue({ args0 -> args0 }))
            .userIdentity(userIdentity?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KeyVaultPropertiesArgs].
 */
@PulumiTagMarker
public class KeyVaultPropertiesArgsBuilder internal constructor() {
    private var keyName: Output<String>? = null

    private var keyVaultUri: Output<String>? = null

    private var keyVersion: Output<String>? = null

    private var userIdentity: Output<String>? = null

    /**
     * @param value The name of the key vault key.
     */
    @JvmName("rmoklknprklfnnqg")
    public suspend fun keyName(`value`: Output<String>) {
        this.keyName = value
    }

    /**
     * @param value The Uri of the key vault.
     */
    @JvmName("faaqplehdtbdgner")
    public suspend fun keyVaultUri(`value`: Output<String>) {
        this.keyVaultUri = value
    }

    /**
     * @param value The version of the key vault key.
     */
    @JvmName("dnrqlacwldjqwgaq")
    public suspend fun keyVersion(`value`: Output<String>) {
        this.keyVersion = value
    }

    /**
     * @param value The user assigned identity (ARM resource id) that has access to the key.
     */
    @JvmName("ctrofuxhlyblbvpl")
    public suspend fun userIdentity(`value`: Output<String>) {
        this.userIdentity = value
    }

    /**
     * @param value The name of the key vault key.
     */
    @JvmName("wvnnclmjnktdrmng")
    public suspend fun keyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyName = mapped
    }

    /**
     * @param value The Uri of the key vault.
     */
    @JvmName("usjrxhmnvreliiec")
    public suspend fun keyVaultUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultUri = mapped
    }

    /**
     * @param value The version of the key vault key.
     */
    @JvmName("nhtcnmydtenbwxni")
    public suspend fun keyVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVersion = mapped
    }

    /**
     * @param value The user assigned identity (ARM resource id) that has access to the key.
     */
    @JvmName("dluvopjvbwwmjxmi")
    public suspend fun userIdentity(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userIdentity = mapped
    }

    internal fun build(): KeyVaultPropertiesArgs = KeyVaultPropertiesArgs(
        keyName = keyName,
        keyVaultUri = keyVaultUri,
        keyVersion = keyVersion,
        userIdentity = userIdentity,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/inputs/KeyVaultPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.inputs

import com.pulumi.azurenative.kusto.inputs.KeyVaultPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of the key vault.
 * @property keyName The name of the key vault key.
 * @property keyVaultUri The Uri of the key vault.
 * @property keyVersion The version of the key vault key.
 * @property userIdentity The user assigned identity (ARM resource id) that has access to the key.
 */
public data class KeyVaultPropertiesArgs(
    public val keyName: Output<String>? = null,
    public val keyVaultUri: Output<String>? = null,
    public val keyVersion: Output<String>? = null,
    public val userIdentity: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.kusto.inputs.KeyVaultPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.kusto.inputs.KeyVaultPropertiesArgs =
        com.pulumi.azurenative.kusto.inputs.KeyVaultPropertiesArgs.builder()
            .keyName(keyName?.applyValue({ args0 -> args0 }))
            .keyVaultUri(keyVaultUri?.applyValue({ args0 -> args0 }))
            .keyVersion(keyVersion?.applyValue({ args0 -> args0 }))
            .userIdentity(userIdentity?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KeyVaultPropertiesArgs].
 */
@PulumiTagMarker
public class KeyVaultPropertiesArgsBuilder internal constructor() {
    private var keyName: Output<String>? = null

    private var keyVaultUri: Output<String>? = null

    private var keyVersion: Output<String>? = null

    private var userIdentity: Output<String>? = null

    /**
     * @param value The name of the key vault key.
     */
    @JvmName("vykusbyqavuhywld")
    public suspend fun keyName(`value`: Output<String>) {
        this.keyName = value
    }

    /**
     * @param value The Uri of the key vault.
     */
    @JvmName("ncgbxieplxxuewii")
    public suspend fun keyVaultUri(`value`: Output<String>) {
        this.keyVaultUri = value
    }

    /**
     * @param value The version of the key vault key.
     */
    @JvmName("ukpmrqlwdapfxomi")
    public suspend fun keyVersion(`value`: Output<String>) {
        this.keyVersion = value
    }

    /**
     * @param value The user assigned identity (ARM resource id) that has access to the key.
     */
    @JvmName("jmynfxofsicyojtw")
    public suspend fun userIdentity(`value`: Output<String>) {
        this.userIdentity = value
    }

    /**
     * @param value The name of the key vault key.
     */
    @JvmName("djagmghdrcqbsdrg")
    public suspend fun keyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyName = mapped
    }

    /**
     * @param value The Uri of the key vault.
     */
    @JvmName("nfwsjphvbgqhrwim")
    public suspend fun keyVaultUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultUri = mapped
    }

    /**
     * @param value The version of the key vault key.
     */
    @JvmName("lrjuptkdseknukgs")
    public suspend fun keyVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVersion = mapped
    }

    /**
     * @param value The user assigned identity (ARM resource id) that has access to the key.
     */
    @JvmName("bxkjorxvmorglgth")
    public suspend fun userIdentity(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userIdentity = mapped
    }

    internal fun build(): KeyVaultPropertiesArgs = KeyVaultPropertiesArgs(
        keyName = keyName,
        keyVaultUri = keyVaultUri,
        keyVersion = keyVersion,
        userIdentity = userIdentity,
    )
}
